opap
========

opap is a library to access OPAP data.

Look how easy it is to use::

    import opap

    opap.get_last_draw("kino")

Features
--------

- Retrieve last draw's results
- Retrieve draw's results from specific draw id
- Retrieve draw's results from an id range
- Retrieve the last n draw's results
- Retrieve draw's results between specific dates
- Retrieve draw id's between specific dates
- Retrieve last draw's id
- Retrieve next draw's id

Installation
------------

Install opap by running::

    pip install opap

License
-------

The project is licensed under the MIT license.